Learn R Programming

smoof (version 1.7.0)

conversion: Conversion between minimization and maximization problems

Description

We can minimize f by maximizing -f. The majority of predefined objective functions in smoof should be minimized by default. However, there are a handful of functions, e.g., Keane or Alpine02, which shall be maximized by default. For benchmarking studies it might be beneficial to inverse the direction. The functions convertToMaximization and convertToMinimization do exactly that, keeping the attributes.

Usage

convertToMaximization(fn)

convertToMinimization(fn)

Value

[smoof_function] Converted smoof function

Arguments

fn

[smoof_function]
Smoof function.

Examples

Run this code
# create a function which should be minimized by default
fn = makeSphereFunction(1L)
print(shouldBeMinimized(fn))
# Now invert the objective direction ...
fn2 = convertToMaximization(fn)
# and invert it again
fn3 = convertToMinimization(fn2)
# Now to convince ourselves we render some plots
opar = par(mfrow = c(1, 3))
plot(fn)
plot(fn2)
plot(fn3)
par(opar)

Run the code above in your browser using DataLab