Learn R Programming

smoof (version 1.7.0)

exportNKFunction: Export/import (rM)NK-landscapes

Description

NK-landscapes and rMNK-landscapes are randomly generated combinatorial structures. In contrast to continuous benchmark function it thus makes perfect sense to store the landscape definitions in a text-based format.

Usage

exportNKFunction(x, path)

importNKFunction(path)

Value

Silently returns TRUE on success.

Arguments

x

[smoof_function]
NK-landscape of rMNK-landscape.

path

[character(1)]
Path to file.

Details

The format uses two comment lines with basic information like the package version, the date of storage etc. The third line contains \(\rho\), \(M\) and \(N\) separated by a single-whitespace. Following that follow epistatic links from which the number of epistatic links can be attracted. There are \(M * N\) lines for a MNK-landscape with \(M\) objectives and input dimension N. The first \(N\) lines contain the links for the first objective an so on. Following that the tabular values follow in the same manner. For every position \(i = 1, \ldots, N\) there is a line with \(2^{K_i + 1}\) values.

Note: exportNKFunction overwrites existing files without asking.

See Also

importNKFunction

Other nk_landscapes: makeMNKFunction(), makeNKFunction()