Learn R Programming

smoof (version 1.7.0)

getLocalOptimum: Returns the local optima of a single objective smoof function

Description

This function returns the parameters and objective values of all local optima (including the global one).

Usage

getLocalOptimum(fn)

Value

[list] List containing the following entries:

param [list]

List of parameter values per local optima.

value [list]

List of objective values per local optima.

is.minimum [logical(1)]

Are the local optima minima or maxima?

Arguments

fn

[smoof_function]
Objective function.