Learn R Programming

smoof (version 1.7.0)

getMeanFunction: Returns the true mean function in the noisy case

Description

Returns the true mean function in the noisy case

Usage

getMeanFunction(fn)

Value

[function] True mean function in the noisy case.

Arguments

fn

[smoof_function]
Objective function.