Learn R Programming

smoof (version 1.7.0)

getNumberOfEvaluations: Returns the number of function evaluations performed by the wrapped smoof_function

Description

Returns the number of function evaluations performed by the wrapped smoof_function

Usage

getNumberOfEvaluations(fn)

Value

[integer(1)] The number of function evaluations.

Arguments

fn

[smoof_counting_function]
Wrapped smoof_function.