Learn R Programming

smoof (version 1.7.0)

hasTags: Checks if the function has assigned special tags

Description

Each single-objective smoof function has tags assigned to it (see getAvailableTags). This little helper returns a vector of assigned tags from a smoof function.

Usage

hasTags(fn, tags)

Value

[logical(1)] Logical vector indicating the presence of specified tags.

Arguments

fn

[smoof_function] Function of smoof_function, a smoof_generator or a string.

tags

[character]
Vector of tags/properties to check fn for.