makeFunctionsByName: Generate smoof function by passing a character vector of generator
names
Description
This function is especially useful in combination with
filterFunctionsByTags to generate a test set of functions
with certain properties, e.~g., multimodality.
Usage
makeFunctionsByName(fun.names, ...)
Value
[smoof_function]
Smoof function generated based on the specified names and arguments.
Arguments
fun.names
[character]
Non empty character vector of generator function names.