Learn R Programming

smoof (version 1.7.0)

makeHolderTableN2Function: Holder Table function N. 2

Description

This multi-modal function is defined as $$f(\mathbf{x}) = -\left|\sin(\mathbf{x}_1)\cos(\mathbf{x}_2)\exp(|1 - \sqrt{\mathbf{x}_1 + \mathbf{x}_2}/\pi|)\right|$$ with box-constraints \(\mathbf{x}_i \in [-10, 10], i = 1, 2\).

Usage

makeHolderTableN2Function()

Arguments

Value

An object of class SingleObjectiveFunction, representing the Holder Table function N. 2 Function.

[smoof_single_objective_function]

References

S. K. Mishra, Global Optimization By Differential Evolution and Particle Swarm Methods: Evaluation On Some Benchmark Functions, Munich Research Papers in Economics.

See Also

makeHolderTableN1Function