Learn R Programming

smoof (version 1.7.0)

makeMMF1eFunction: MMF1e Function

Description

Test problem from the set of "multi-modal multi-objective functions" as for instance used in the CEC2019 competition.

Usage

makeMMF1eFunction(a = exp(1L))

Value

[smoof_multi_objective_function] Returns an instance of the MMF1e function as a smoof_multi_objective_function object.

Arguments

a

[double(1)]
Parametrizable factor. In the CEC2019 competition, the organizers used a = exp(1L).

References

Caitong Yue, Boyang Qu, Kunjie Yu, Jing Liang, and Xiaodong Li, "A novel scalable test problem suite for multimodal multiobjective optimization," in Swarm and Evolutionary Computation, Volume 48, August 2019, pp. 62–71, Elsevier.