Internal generator for function of smoof type
makeObjectiveFunction(
name = NULL,
id = NULL,
description = NULL,
fn,
has.simple.signature = TRUE,
par.set,
n.objectives = NULL,
noisy = FALSE,
fn.mean = NULL,
minimize = NULL,
vectorized = FALSE,
constraint.fn = NULL
)[function] Target function with additional stuff attached as attributes.
[character(1)]
Optional function name used e.g. in plots.
[character(1)]
Optional identifier for the function
[character(1) | NULL]
Optional function description.
[function]
Target function.
[logical(1)]
Set this to TRUE if the target function expects a vector as input and FALSE
if it expects a named list of values. The latter is needed if the function depends on mixed
parameters. Default is TRUE.
[ParamSet]
Parameter set describing different aspects of the target function parameters, i. e.,
names, lower and/or upper bounds, types and so on. See makeParamSet
for further information.
[integer(1)]
Number of objectives of the multi-objective function.
[logical(1)]
Is the function noisy? Defaults to FALSE.
[function]
Optional true mean function in case of a noisy objective function. This functions should
have the same mean as fn.
[logical]
Logical vector of length n.objectives indicating which objectives shall
be minimized/maximized.
The default is TRUE n.objectives times.
[logical(1)]
Can the handle “vector” input, i. e., does it accept matrix of
parameters? Default is FALSE.
[function | NULL]
Function which returns a logical vector indicating which indicates whether certain conditions
are met or not. Default is NULL, which means, that there are no constraints (beside possible)
box constraints defined via the par.set argument.