Learn R Programming

smoof (version 1.7.0)

makeOmniTestFunction: MMF13 Function

Description

Test problem from the set of "multimodal multiobjective functions" as for instance used in the CEC2019 competition.

Usage

makeOmniTestFunction()

Arguments

Value

[smoof_multi_objective_function] Returns an instance of the Omni function as a smoof_multi_objective_function object.

References

Caitong Yue, Boyang Qu, Kunjie Yu, Jing Liang, and Xiaodong Li, "A novel scalable test problem suite for multimodal multiobjective optimization," in Swarm and Evolutionary Computation, Volume 48, August 2019, pp. 62–71, Elsevier.