doesCountEvaluations: Check whether the function is counting its function evaluations
Description
In this case, the function is of type smoof_counting_function or it
is further wrapped by another wrapper. This function then checks recursively,
if there is a counting wrapper.
Usage
doesCountEvaluations(object)
Value
logical(1)
TRUE if the function counts its evaluations, FALSE otherwise.
Arguments
- object
[any]
Arbitrary R object.