Dixon and Price defined the function $$f(\mathbf{x}) = (\mathbf{x}_1 - 1)^2 + \sum_{i = 1}^{n} i (2\mathbf{x}_i^2 - \mathbf{x}_{i - 1})$$ subject to \(\mathbf{x}_i \in [-10, 10]\) for \(i = 1, \ldots, n\).
makeDixonPriceFunction(dimensions)An object of class SingleObjectiveFunction, representing the Dixon-Price Function.
[smoof_single_objective_function]
[integer(1)]
Size of corresponding parameter space.
L. C. W. Dixon, R. C. Price, The Truncated Newton Method for Sparse Unconstrained Optimisation Using Automatic Differentiation, Journal of Optimization Theory and Applications, vol. 60, no. 2, pp. 261-275, 1989.