Single-objective test function based on the formula $$f(\mathbf{x}) = \frac{1}{n} \sum_{i = 1}^{n} \sin(10 \log(\mathbf{x}_i))$$ subject to \(\mathbf{x}_i \in [0.25, 10]\) for \(i = 1, \ldots, n\).
makeInvertedVincentFunction(dimensions)An object of class SingleObjectiveFunction, representing the Inverted Vincent Function.
[smoof_single_objective_function]
[integer(1)]
Size of corresponding parameter space.
Xiadong Li, Andries Engelbrecht, and Michael G. Epitropakis. Benchmark functions for CEC2013 special session and competition on niching methods for multi-modal function optimization. Technical report, RMIT University, Evolutionary Computation and Machine Learning Group, Australia, 2013.