Test problem from the set of "multi-modal multi-objective functions" as for instance used in the CEC2019 competition.
makeMMF1eFunction(a = exp(1L))[smoof_multi_objective_function]
Returns an instance of the MMF1e function as a smoof_multi_objective_function object.
[double(1)]
Parametrizable factor. In the CEC2019 competition, the organizers used
a = exp(1L).
Caitong Yue, Boyang Qu, Kunjie Yu, Jing Liang, and Xiaodong Li, "A novel scalable test problem suite for multimodal multiobjective optimization," in Swarm and Evolutionary Computation, Volume 48, August 2019, pp. 62–71, Elsevier.